django-dajaxice — django-dajaxice v0.1.8 documentation

### Navigation

- index
- next |
- django-dajaxice v0.1.8 documentation »

# django-dajaxice

Dajaxixe is an Easy to use AJAX library for django. Its main goal is to trivialize the asynchronous communication within the django server code and your js code. Dajaxice uses the unobtrusive standard-compliant (W3C) XMLHttpRequest 1.0 object.

django-dajaxice is a JS-framework agnostic library and focuses on decoupling the presentation logic from the server-side logic. dajaxice only requieres 5 minutes to start working.

Dajaxice has the following aims:

- Isolate the communication between the client and the server.
- JS Framework agnostic (No Prototype, JQuery... needed ).
- Presentation logic outside the views (No presentation code inside ajax functions).
- Lightweight.
- Crossbrowsing ready.
- Unobtrusive standard-compliant (W3C) XMLHttpRequest 1.0 object usage.

## Documentation

- Installation
  - Installing dajaxice
  - Configure dajaxice url
  - Install dajaxice in your templates
  - Use Dajaxice!
- Quickstart
  - Create your first ajax function
  - Invoque it from your JS
  - How can I do a GET request instead of a POST one?
  - Can I combine both?
- Custom error callbacks
  - How dajaxice handle errors
  - Customize the default error message
  - Customize error message per call
- Production Environment
- Migrating to 0.5
  - Upgrade to django 1.3 or 1.4
  - Make django static-files work
  - Update dajaxice core url
  - Done!
- Available Settings
  - DAJAXICE_MEDIA_PREFIX
  - DAJAXICE_XMLHTTPREQUEST_JS_IMPORT
  - DAJAXICE_JSON2_JS_IMPORT
  - DAJAXICE_EXCEPTION
- Changelog
  - 0.5
  - 0.2
  - 0.1.8.1
  - 0.1.8
  - 0.1.7
  - 0.1.6
  - 0.1.5
  - 0.1.3
  - 0.1.2
  - 0.1.1
  - 0.1.0
  - 0.0.1

# Indices and tables

- Index
- Module Index
- Search Page

### Navigation

- index
- next |
- django-dajaxice v0.1.8 documentation »